@@ -40,7 +40,7 @@ class SubmissionFlair:
 
         .. code-block:: python
 
-           choices = submission.flair.choices()
+            choices = submission.flair.choices()
 
         """
         url = API_PATH["flairselector"].format(subreddit=self.submission.subreddit)
@@ -52,20 +52,18 @@ class SubmissionFlair:
         """Select flair for submission.
 
         :param flair_template_id: The flair template to select. The possible
-            ``flair_template_id`` values can be discovered through
-            :meth:`.choices`.
-        :param text: If the template's ``flair_text_editable`` value is True,
-            this value will set a custom text (default: None).
+            ``flair_template_id`` values can be discovered through :meth:`.choices`.
+        :param text: If the template's ``flair_text_editable`` value is True, this value
+            will set a custom text (default: None).
 
-        For example, to select an arbitrary editable flair text (assuming there
-        is one) and set a custom value try:
+        For example, to select an arbitrary editable flair text (assuming there is one)
+        and set a custom value try:
 
         .. code-block:: python
 
-           choices = submission.flair.choices()
-           template_id = next(x for x in choices
-                              if x["flair_text_editable"])["flair_template_id"]
-           submission.flair.select(template_id, "my custom value")
+            choices = submission.flair.choices()
+            template_id = next(x for x in choices if x["flair_text_editable"])["flair_template_id"]
+            submission.flair.select(template_id, "my custom value")
 
         """
         data = {
@@ -84,8 +82,8 @@ class SubmissionModeration(ThingModerationMixin):
 
     .. code-block:: python
 
-       submission = reddit.submission(id="8dmv8z")
-       submission.mod.approve()
+        submission = reddit.submission(id="8dmv8z")
+        submission.mod.approve()
 
     """
 
@@ -102,27 +100,28 @@ class SubmissionModeration(ThingModerationMixin):
     def contest_mode(self, state: bool = True):
         """Set contest mode for the comments of this submission.
 
-        :param state: (boolean) True enables contest mode, False, disables
-            (default: True).
+        :param state: (boolean) True enables contest mode, False, disables (default:
+            True).
 
         Contest mode have the following effects:
-          * The comment thread will default to being sorted randomly.
-          * Replies to top-level comments will be hidden behind
-            "[show replies]" buttons.
-          * Scores will be hidden from non-moderators.
-          * Scores accessed through the API (mobile apps, bots) will be
-            obscured to "1" for non-moderators.
+
+        * The comment thread will default to being sorted randomly.
+        * Replies to top-level comments will be hidden behind "[show replies]" buttons.
+        * Scores will be hidden from non-moderators.
+        * Scores accessed through the API (mobile apps, bots) will be obscured to "1"
+          for non-moderators.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mod.contest_mode(state=True)
+            submission = reddit.submission(id="5or86n")
+            submission.mod.contest_mode(state=True)
 
         """
         self.thing._reddit.post(
-            API_PATH["contest_mode"], data={"id": self.thing.fullname, "state": state},
+            API_PATH["contest_mode"],
+            data={"id": self.thing.fullname, "state": state},
         )
 
     def flair(
@@ -133,22 +132,19 @@ class SubmissionModeration(ThingModerationMixin):
     ):
         """Set flair for the submission.
 
-        :param text: The flair text to associate with the Submission (default:
-            '').
-        :param css_class: The css class to associate with the flair html
-            (default: '').
-        :param flair_template_id: The flair template id to use when flairing
-            (Optional).
+        :param text: The flair text to associate with the Submission (default: "").
+        :param css_class: The css class to associate with the flair html (default: "").
+        :param flair_template_id: The flair template id to use when flairing (Optional).
 
-        This method can only be used by an authenticated user who is a
-        moderator of the Submission's Subreddit.
+        This method can only be used by an authenticated user who is a moderator of the
+        Submission's Subreddit.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mod.flair(text="PRAW", css_class="bot")
+            submission = reddit.submission(id="5or86n")
+            submission.mod.flair(text="PRAW", css_class="bot")
 
         """
         data = {
@@ -165,18 +161,19 @@ class SubmissionModeration(ThingModerationMixin):
     def nsfw(self):
         """Mark as not safe for work.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.subreddit("test").submit("nsfw test",
-                                                        selftext="nsfw")
-           submission.mod.nsfw()
+            submission = reddit.subreddit("test").submit("nsfw test", selftext="nsfw")
+            submission.mod.nsfw()
 
-        .. seealso:: :meth:`~.sfw`
+        .. seealso::
+
+            :meth:`~.sfw`
 
         """
         self.thing._reddit.post(API_PATH["marknsfw"], data={"id": self.thing.fullname})
@@ -184,20 +181,20 @@ class SubmissionModeration(ThingModerationMixin):
     def set_original_content(self):
         """Mark as original content.
 
-        This method can be used by moderators of the subreddit that the
-        submission belongs to. If the subreddit has enabled the Original
-        Content beta feature in settings, then the submission's author
-        can use it as well.
+        This method can be used by moderators of the subreddit that the submission
+        belongs to. If the subreddit has enabled the Original Content beta feature in
+        settings, then the submission's author can use it as well.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.subreddit("test").submit("oc test",
-                                                        selftext="original")
-           submission.mod.set_original_content()
+            submission = reddit.subreddit("test").submit("oc test", selftext="original")
+            submission.mod.set_original_content()
 
-        .. seealso:: :meth:`.unset_original_content`
+        .. seealso::
+
+            :meth:`.unset_original_content`
 
         """
         data = {
@@ -212,17 +209,19 @@ class SubmissionModeration(ThingModerationMixin):
     def sfw(self):
         """Mark as safe for work.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mod.sfw()
+            submission = reddit.submission(id="5or86n")
+            submission.mod.sfw()
 
-        .. seealso:: :meth:`~.nsfw`
+        .. seealso::
+
+            :meth:`~.nsfw`
 
         """
         self.thing._reddit.post(
@@ -232,17 +231,19 @@ class SubmissionModeration(ThingModerationMixin):
     def spoiler(self):
         """Indicate that the submission contains spoilers.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mod.spoiler()
+            submission = reddit.submission(id="5or86n")
+            submission.mod.spoiler()
 
-        .. seealso:: :meth:`~.unspoiler`
+        .. seealso::
+
+            :meth:`~.unspoiler`
 
         """
         self.thing._reddit.post(API_PATH["spoiler"], data={"id": self.thing.fullname})
@@ -250,25 +251,26 @@ class SubmissionModeration(ThingModerationMixin):
     def sticky(self, state: bool = True, bottom: bool = True):
         """Set the submission's sticky state in its subreddit.
 
-        :param state: (boolean) True sets the sticky for the submission, false
-            unsets (default: True).
-        :param bottom: (boolean) When true, set the submission as the bottom
-            sticky. If no top sticky exists, this submission will become the
-            top sticky regardless (default: True).
+        :param state: (boolean) True sets the sticky for the submission, false unsets
+            (default: True).
+        :param bottom: (boolean) When true, set the submission as the bottom sticky. If
+            no top sticky exists, this submission will become the top sticky regardless
+            (default: True).
 
-        .. note:: When a submission is stickied two or more times, the Reddit
-            API responds with a 409 error that is raises as a ``Conflict`` by
-            PRAWCore. The method suppresses these ``Conflict`` errors.
+        .. note::
 
-        This submission will replace the second stickied submission if one
-        exists.
+            When a submission is stickied two or more times, the Reddit API responds
+            with a 409 error that is raises as a ``Conflict`` by prawcore. The method
+            suppresses these ``Conflict`` errors.
+
+        This submission will replace the second stickied submission if one exists.
 
         For example:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mod.sticky()
+            submission = reddit.submission(id="5or86n")
+            submission.mod.sticky()
 
         """
         data = {"id": self.thing.fullname, "state": state}
@@ -282,31 +284,32 @@ class SubmissionModeration(ThingModerationMixin):
     def suggested_sort(self, sort: str = "blank"):
         """Set the suggested sort for the comments of the submission.
 
-        :param sort: Can be one of: confidence, top, new, controversial, old,
-            random, qa, blank (default: blank).
+        :param sort: Can be one of: confidence, top, new, controversial, old, random,
+            qa, blank (default: blank).
 
         """
         self.thing._reddit.post(
-            API_PATH["suggested_sort"], data={"id": self.thing.fullname, "sort": sort},
+            API_PATH["suggested_sort"],
+            data={"id": self.thing.fullname, "sort": sort},
         )
 
     def unset_original_content(self):
         """Indicate that the submission is not original content.
 
-        This method can be used by moderators of the subreddit that the
-        submission belongs to. If the subreddit has enabled the Original
-        Content beta feature in settings, then the submission's author
-        can use it as well.
+        This method can be used by moderators of the subreddit that the submission
+        belongs to. If the subreddit has enabled the Original Content beta feature in
+        settings, then the submission's author can use it as well.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.subreddit("test").submit("oc test",
-                                                        selftext="original")
-           submission.mod.unset_original_content()
+            submission = reddit.subreddit("test").submit("oc test", selftext="original")
+            submission.mod.unset_original_content()
 
-        .. seealso:: :meth:`.set_original_content`
+        .. seealso::
+
+            :meth:`.set_original_content`
 
         """
         data = {
@@ -321,18 +324,19 @@ class SubmissionModeration(ThingModerationMixin):
     def unspoiler(self):
         """Indicate that the submission does not contain spoilers.
 
-        This method can be used both by the submission author and moderators of
-        the subreddit that the submission belongs to.
+        This method can be used both by the submission author and moderators of the
+        subreddit that the submission belongs to.
 
         For example:
 
         .. code-block:: python
 
-           submission = reddit.subreddit("test").submit("not spoiler",
-                                                        selftext="spoiler")
-           submission.mod.unspoiler()
+            submission = reddit.subreddit("test").submit("not spoiler", selftext="spoiler")
+            submission.mod.unspoiler()
 
-        .. seealso:: :meth:`~.spoiler`
+        .. seealso::
+
+            :meth:`~.spoiler`
 
         """
         self.thing._reddit.post(API_PATH["unspoiler"], data={"id": self.thing.fullname})
@@ -343,54 +347,49 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    =========================== ===============================================
+    =========================== ========================================================
     Attribute                   Description
-    =========================== ===============================================
+    =========================== ========================================================
     ``author``                  Provides an instance of :class:`.Redditor`.
-    ``clicked``                 Whether or not the submission has been clicked
-                                by the client.
-    ``comments``                Provides an instance of
-                                :class:`.CommentForest`.
-    ``created_utc``             Time the submission was created, represented in
-                                `Unix Time`_.
+    ``clicked``                 Whether or not the submission has been clicked by the
+                                client.
+    ``comments``                Provides an instance of :class:`.CommentForest`.
+    ``created_utc``             Time the submission was created, represented in `Unix
+                                Time`_.
     ``distinguished``           Whether or not the submission is distinguished.
     ``edited``                  Whether or not the submission has been edited.
     ``id``                      ID of the submission.
-    ``is_original_content``     Whether or not the submission has been set
-                                as original content.
-    ``is_self``                 Whether or not the submission is a selfpost
-                                (text-only).
+    ``is_original_content``     Whether or not the submission has been set as original
+                                content.
+    ``is_self``                 Whether or not the submission is a selfpost (text-only).
     ``link_flair_template_id``  The link flair's ID, or None if not flaired.
-    ``link_flair_text``         The link flair's text content, or None if not
-                                flaired.
+    ``link_flair_text``         The link flair's text content, or None if not flaired.
     ``locked``                  Whether or not the submission has been locked.
     ``name``                    Fullname of the submission.
     ``num_comments``            The number of comments on the submission.
-    ``over_18``                 Whether or not the submission has been marked
-                                as NSFW.
+    ``over_18``                 Whether or not the submission has been marked as NSFW.
     ``permalink``               A permalink for the submission.
-    ``poll_data``               A :class:`.PollData` object representing the
-                                data of this submission, if it is a poll
-                                submission.
+    ``poll_data``               A :class:`.PollData` object representing the data of
+                                this submission, if it is a poll submission.
+    ``saved``                   Whether or not the submission is saved.
     ``score``                   The number of upvotes for the submission.
-    ``selftext``                The submissions' selftext - an empty string if
-                                a link post.
-    ``spoiler``                 Whether or not the submission has been marked
-                                as a spoiler.
+    ``selftext``                The submissions' selftext - an empty string if a link
+                                post.
+    ``spoiler``                 Whether or not the submission has been marked as a
+                                spoiler.
     ``stickied``                Whether or not the submission is stickied.
     ``subreddit``               Provides an instance of :class:`.Subreddit`.
     ``title``                   The title of the submission.
     ``upvote_ratio``            The percentage of upvotes from all votes on the
                                 submission.
-    ``url``                     The URL the submission links to, or the
-                                permalink if a selfpost.
-    =========================== ===============================================
+    ``url``                     The URL the submission links to, or the permalink if a
+                                selfpost.
+    =========================== ========================================================
 
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
@@ -403,23 +402,31 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def id_from_url(url: str) -> str:
         """Return the ID contained within a submission URL.
 
-        :param url: A url to a submission in one of the following formats (http
-            urls will also work):
+        :param url: A url to a submission in one of the following formats (http urls
+            will also work):
 
             * https://redd.it/2gmzqe
             * https://reddit.com/comments/2gmzqe/
             * https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https/
+            * https://www.reddit.com/gallery/2gmzqe
 
         :raises: :class:`.InvalidURL` if URL is not a valid submission URL.
 
         """
         parts = RedditBase._url_parts(url)
-        if "comments" not in parts:
+        if "comments" not in parts and "gallery" not in parts:
             submission_id = parts[-1]
             if "r" in parts:
                 raise InvalidURL(
                     url, message="Invalid URL (subreddit, not submission): {}"
                 )
+
+        elif "gallery" in parts:
+            submission_id = parts[parts.index("gallery") + 1]
+
+        elif parts[-1] == "comments":
+            raise InvalidURL(url, message="Invalid URL (submission id not present): {}")
+
         else:
             submission_id = parts[parts.index("comments") + 1]
 
@@ -436,26 +443,27 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def comments(self) -> CommentForest:
         """Provide an instance of :class:`.CommentForest`.
 
-        This attribute can use used, for example, to obtain a flat list of
-        comments, with any :class:`.MoreComments` removed:
+        This attribute can be used, for example, to obtain a flat list of comments, with
+        any :class:`.MoreComments` removed:
 
         .. code-block:: python
 
-           submission.comments.replace_more(limit=0)
-           comments = submission.comments.list()
+            submission.comments.replace_more(limit=0)
+            comments = submission.comments.list()
 
         Sort order and comment limit can be set with the ``comment_sort`` and
-        ``comment_limit`` attributes before comments are fetched, including
-        any call to :meth:`.replace_more`:
+        ``comment_limit`` attributes before comments are fetched, including any call to
+        :meth:`.replace_more`:
 
         .. code-block:: python
 
-           submission.comment_sort = "new"
-           comments = submission.comments.list()
+            submission.comment_sort = "new"
+            comments = submission.comments.list()
 
-        .. note:: The appropriate values for ``comment_sort`` include
-           ``confidence``, ``controversial``, ``new``, ``old``, ``q&a``,
-           and ``top``
+        .. note::
+
+            The appropriate values for ``comment_sort`` include ``confidence``,
+            ``controversial``, ``new``, ``old``, ``q&a``, and ``top``
 
         See :ref:`extracting_comments` for more on working with a
         :class:`.CommentForest`.
@@ -468,19 +476,17 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def flair(self) -> SubmissionFlair:
         """Provide an instance of :class:`.SubmissionFlair`.
 
-        This attribute is used to work with flair as a regular user of the
-        subreddit the submission belongs to. Moderators can directly use
-        :meth:`.flair`.
+        This attribute is used to work with flair as a regular user of the subreddit the
+        submission belongs to. Moderators can directly use :meth:`.flair`.
 
-        For example, to select an arbitrary editable flair text (assuming there
-        is one) and set a custom value try:
+        For example, to select an arbitrary editable flair text (assuming there is one)
+        and set a custom value try:
 
         .. code-block:: python
 
-           choices = submission.flair.choices()
-           template_id = next(x for x in choices
-                              if x["flair_text_editable"])["flair_template_id"]
-           submission.flair.select(template_id, "my custom value")
+            choices = submission.flair.choices()
+            template_id = next(x for x in choices if x["flair_text_editable"])["flair_template_id"]
+            submission.flair.select(template_id, "my custom value")
 
         """
         return SubmissionFlair(self)
@@ -493,8 +499,8 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-           submission = reddit.submission(id="8dmv8z")
-           submission.mod.approve()
+            submission = reddit.submission(id="8dmv8z")
+            submission.mod.approve()
 
         """
         return SubmissionModeration(self)
@@ -503,7 +509,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def shortlink(self) -> str:
         """Return a shortlink to the submission.
 
-        For example http://redd.it/eorhm is a shortlink for
+        For example https://redd.it/eorhm is a shortlink for
         https://www.reddit.com/r/announcements/comments/eorhm/reddit_30_less_typing/.
 
         """
@@ -520,25 +526,25 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         :param reddit: An instance of :class:`~.Reddit`.
         :param id: A reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by
-            :meth:`~praw.models.Submission.id_from_url`.
+        :param url: A URL supported by :meth:`~praw.models.Submission.id_from_url`.
 
         Either ``id`` or ``url`` can be provided, but not both.
 
         """
         if (id, url, _data).count(None) != 2:
             raise TypeError("Exactly one of `id`, `url`, or `_data` must be provided.")
-        super().__init__(reddit, _data=_data)
         self.comment_limit = 2048
 
         # Specify the sort order for ``comments``
         self.comment_sort = "confidence"
 
-        if id is not None:
+        if id:
             self.id = id
-        elif url is not None:
+        elif url:
             self.id = self.id_from_url(url)
 
+        super().__init__(reddit, _data=_data)
+
         self._comments_by_id = {}
 
     def __setattr__(self, attribute: str, value: Any):
@@ -596,8 +602,8 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.mark_visited()
+            submission = reddit.submission(id="5or86n")
+            submission.mark_visited()
 
         """
         data = {"links": self.fullname}
@@ -606,18 +612,19 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def hide(self, other_submissions: Optional[List["Submission"]] = None):
         """Hide Submission.
 
-        :param other_submissions: When provided, additionally
-            hide this list of :class:`.Submission` instances
-            as part of a single request (default: None).
+        :param other_submissions: When provided, additionally hide this list of
+            :class:`.Submission` instances as part of a single request (default: None).
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.hide()
+            submission = reddit.submission(id="5or86n")
+            submission.hide()
 
-        .. seealso:: :meth:`~.unhide`
+        .. seealso::
+
+            :meth:`~.unhide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -626,18 +633,19 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
     def unhide(self, other_submissions: Optional[List["Submission"]] = None):
         """Unhide Submission.
 
-        :param other_submissions: When provided, additionally
-            unhide this list of :class:`.Submission` instances
-            as part of a single request (default: None).
+        :param other_submissions: When provided, additionally unhide this list of
+            :class:`.Submission` instances as part of a single request (default: None).
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           submission.unhide()
+            submission = reddit.submission(id="5or86n")
+            submission.unhide()
 
-        .. seealso:: :meth:`~.hide`
+        .. seealso::
+
+            :meth:`~.hide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -656,34 +664,34 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         """Crosspost the submission to a subreddit.
 
         .. note::
+
             Be aware you have to be subscribed to the target subreddit.
 
-        :param subreddit: Name of the subreddit or :class:`~.Subreddit`
-            object to crosspost into.
-        :param title: Title of the submission. Will use this submission's
-            title if `None` (default: None).
+        :param subreddit: Name of the subreddit or :class:`~.Subreddit` object to
+            crosspost into.
+        :param title: Title of the submission. Will use this submission's title if
+            `None` (default: None).
         :param flair_id: The flair template to select (default: None).
-        :param flair_text: If the template's ``flair_text_editable`` value is
-            True, this value will set a custom text (default: None).
-        :param send_replies: When True, messages will be sent to the
-            submission author when comments are made to the submission
-            (default: True).
-        :param nsfw: Whether or not the submission should be marked NSFW
+        :param flair_text: If the template's ``flair_text_editable`` value is True, this
+            value will set a custom text (default: None).
+        :param send_replies: When True, messages will be sent to the submission author
+            when comments are made to the submission (default: True).
+        :param nsfw: Whether or not the submission should be marked NSFW (default:
+            False).
+        :param spoiler: Whether or not the submission should be marked as a spoiler
             (default: False).
-        :param spoiler: Whether or not the submission should be marked as
-            a spoiler (default: False).
-        :returns: A :class:`~.Submission` object for the newly created
-            submission.
+        :returns: A :class:`~.Submission` object for the newly created submission.
 
         Example usage:
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
-           cross_post = submission.crosspost(subreddit="learnprogramming",
-                                             send_replies=False)
+            submission = reddit.submission(id="5or86n")
+            cross_post = submission.crosspost(subreddit="learnprogramming", send_replies=False)
 
-        .. seealso:: :meth:`~.hide`
+        .. seealso::
+
+            :meth:`~.hide`
 
         """
         if title is None:
